@@ -1,10 +1,9 @@
-use v5.16;
-
 package Module::Release::WebUpload::Mojo;
 
 use strict;
 use warnings;
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw($VERSION);
 
 use Carp qw(croak);
 use Mojo::UserAgent;
@@ -17,7 +16,7 @@ our @EXPORT = qw(
 	pause_add_uri
 	);
 
-our $VERSION = '2.127_04';
+$VERSION = '2.07';
 
 =encoding utf8
 
@@ -57,31 +56,23 @@ sub web_upload {
 
 	$self->_print( "File uploading\n" );
 	my $tx = $ua->post(
-		$self->pause_add_uri(
-		 	$self->config->cpan_user,
+		$self->pause_add_uri( 
+		 	$self->config->cpan_user, 
 		 	$self->config->cpan_pass,
 		 	),
 		 form => $params,
 		 );
-
-	if( my $res = eval { $tx->result } ) {
-		$self->_print( "File uploaded\n" );
-		return 1;
-		}
-	else {
-		my $err = $tx->res->error;
-		$self->_print( "$err->{code} response: $err->{message}" ) if $err->{code};
-		$self->_print( "Connection error: $err->{message}" );
-		return 0;
-		}
+	my $code = $tx->res->code;
+	$self->_print( "File uploaded [$code]\n" );
 	}
 
 sub make_agent {
 	my( $self ) = @_;
-	my $agent = Mojo::UserAgent->new;
-	$agent->transactor->name( 'release' );
-	$agent->http_proxy( $self->config->http_proxy )   if $self->config->http_proxy;
+	my $agent = Mojo::UserAgent->new( name => 'release' );
+	$agent->http_proxy( $self->config->http_proxy ) if $self->config->http_proxy;
 	$agent->https_proxy( $self->config->https_proxy ) if $self->config->https_proxy;
+	require CACertOrg::CA;
+	$agent->cert( CACertOrg::CA::SSL_ca_file() );
 
 	return $agent;
 	}
@@ -120,7 +111,7 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-This source is in GitHub
+This source is in Github:
 
 	https://github.com/briandfoy/module-release
 
@@ -130,10 +121,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2021, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
 
-This program is free software; you can redistribute it and/or modify
-it under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
